==> epsagon-1.0.0.tar.gz: epsagon-1.0.0/setup.py <==
#!/usr/bin/env python
import re
import os
from setuptools import setup, find_packages

try:
    # For pip >= 10.
    from pip._internal.req import parse_requirements
    from pip._internal.download import PipSession
except ImportError:
    # For pip <= 9.0.3.
    from pip.req import parse_requirements
    from pip.download import PipSession

install_reqs = parse_requirements('./requirements.txt', session=PipSession())
reqs = [str(ir.req) for ir in install_reqs]

# Get version
with open(os.path.join('epsagon', 'constants.py'), 'rt') as consts_file:
    version = re.search(r'__version__ = \'(.*?)\'', consts_file.read()).group(1)

setup(
    name='epsagon',
    version=version,
    description='Epsagon Library For Python',
    author='Epsagon',
    author_email='support@epsagon.com',
    url='https://github.com/epsagon/epsagon-python',
    packages=find_packages(exclude=('tests', 'examples')),
    install_requires=reqs,
    license='MIT',
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    keywords=[
        'serverless',
        'epsagon',
        'tracing',
        'lambda',
        'awslambda',
        'debugging'
    ],
    classifiers=(
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    )
)

==> epsagon-1.0.1.tar.gz: epsagon-1.0.1/setup.py <==
#!/usr/bin/env python
import re
import os
from setuptools import setup, find_packages

try:
    # For pip >= 10.
    from pip._internal.req import parse_requirements
    from pip._internal.download import PipSession
except ImportError:
    # For pip <= 9.0.3.
    from pip.req import parse_requirements
    from pip.download import PipSession

try:
    from pypandoc import convert

    README = convert('README.md', 'rst')
except (ImportError, OSError):
    README = open(
        os.path.join(os.path.dirname(__file__), 'README.md'), 'r'
    ).read()

install_reqs = parse_requirements('./requirements.txt', session=PipSession())
reqs = [str(ir.req) for ir in install_reqs]

# Get version
with open(os.path.join('epsagon', 'constants.py'), 'rt') as consts_file:
    version = re.search(r'__version__ = \'(.*?)\'', consts_file.read()).group(1)

setup(
    name='epsagon',
    version=version,
    description='Epsagon Instrumentation for Python',
    author='Epsagon',
    author_email='support@epsagon.com',
    url='https://github.com/epsagon/epsagon-python',
    packages=find_packages(exclude=('tests', 'examples')),
    install_requires=reqs,
    license='MIT',
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    keywords=[
        'serverless',
        'epsagon',
        'tracing',
        'distributed-tracing',
        'lambda',
        'aws-lambda',
        'debugging',
        'monitoring'
    ],
    classifiers=(
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    )
)
